Documentation
¶
Index ¶
- func BlobPath(instDir string) string
- type Snap
- func (s *Snap) Build(buildDir string) error
- func (s *Snap) Close() error
- func (s *Snap) ControlMember(controlMember string) ([]byte, error)
- func (s *Snap) ExtractHashes(dir string) error
- func (s *Snap) HashDigest(hash crypto.Hash) (uint64, []byte, error)
- func (s *Snap) MetaMember(metaMember string) ([]byte, error)
- func (s *Snap) Name() string
- func (s *Snap) NeedsMountUnit() bool
- func (s *Snap) ReadFile(path string) (content []byte, err error)
- func (s *Snap) Unpack(src, dstDir string) error
- func (s *Snap) UnpackWithDropPrivs(instDir, rootdir string) error
- func (s *Snap) Verify(unauthOk bool) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Snap ¶
type Snap struct {
// contains filtered or unexported fields
}
Snap is the squashfs based snap.
func (*Snap) ControlMember ¶
ControlMember extracts from meta/ - COMPAT
func (*Snap) ExtractHashes ¶
ExtractHashes does notthing for squashfs snaps. - COMAPT
func (*Snap) HashDigest ¶
HashDigest computes a hash digest of the snap file using the given hash. It also returns its size.
func (*Snap) MetaMember ¶
MetaMember extracts from meta/. - COMPAT
func (*Snap) NeedsMountUnit ¶
NeedsMountUnit returns true because a squashfs snap neesd to be monted, it will not be usable otherwise
func (*Snap) UnpackWithDropPrivs ¶
UnpackWithDropPrivs just copies the blob into place. - COMPAT
Click to show internal directories.
Click to hide internal directories.